/*
 * Astro Info - a an astronomical calculator/almanac for PalmOS devices.
 * 
 * $Id: Astro.h,v 1.11 2000/09/27 20:36:56 mheinz Exp $
 * Copyright (C) 2000, Michael Heinz
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
#ifndef Astro_h
#define Astro_h

/* Max length of all text fields */
#define FIELDLENGTH     16

/* Length of bar charts */
#define BARSIZE 32.0

/* Application Preferences */
typedef struct {
    char                version;       // validates the prefs structure
    int                 tz_h, tz_m;
    double              tz;
    int                 lat_d, lat_m;
    int                 lng_d, lng_m;
    double              lat, lng;
    DateTimeType        currentDT;
    UInt16              activeFormId;  // The page we were on last time
    Boolean             nightMode;     // Whether or not color mode is enabled.
    UInt16              catCardNo;     // The RAM bank containing the catalog.
    char                catDbName[33]; // The name of the most recent catalog.
} MoonPrefsType;

/* Catalog AppInfo */
typedef struct {
    UInt16              numRecords;
    UInt16              currRecord;
} AstroAppInfoType;

/* Catalog Record Type */
typedef struct {
    char description[32];
    UInt16 raH, raM, raS;
    UInt16 decD, decM, decS;
    char magnitude[5];
    char size[9];
} AstroRecordType;

#define ASTRODBTYPE    'DATA'

// The following constant needs to be incremented everytime something
// changes in the astro.rcp file, or in the format of the MoonPrefs
// data.  This constant is written to the saved preferences, allowing
// us to verify that they are not obsolete when we start.  (see the
// MoonPrefsType, above.)
#define ASTROVERSION   113

/*
 * Needed by other code sections
 */
extern MoonPrefsType moonPrefs;
extern UInt16 saveFormId;
extern char datestr[];
extern char timestr[];
extern UInt16 mainMenu;

/*
 * Various functions related to updating the AstroInfo GUI.
 */
void SetDate(ControlPtr dP);
void SetTime(ControlPtr tP);
void SetNow(ControlPtr dP, ControlPtr tP);
void ChangeDate(ControlPtr dP, long days);
void NightMode();
Boolean DoMenu(UInt16 itemID);
void UpdateTextField(FieldPtr fld, char *t);
void UpdateTimeField(FieldPtr fld, double num, int st);

/*
 * Converts hms to floating point hours. 
 */
#define doubletime(h, m, s) (h + m / 60.0 + s / 3600.0)

#endif
