/*
 * Astro Info - a an astronomical calculator/almanac for PalmOS devices.
 * 
 * $Id: constants.h,v 1.6 2000/08/19 14:35:38 mheinz Exp $
 * Copyright (C) 2000, Michael Heinz
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#ifndef constants_h
#define constants_h

/*
 * Constants
 */
#define PI      3.14159265358979323846264338327950288
#define PI_2    (PI * 2)
#define PIh     1.57079632679489661923132169163975144
#define DR      0.01745329252

/*
 * EPOCH is 1990.
 */
#define EPOCH   2447891.5
#define YEAR    365.242191

/*
 * Estimated index of refraction for things on the horizon
 * (in radians)
 */
#define IOR_EST 0.0098901991

/*
 * Solar constants
 */
 
/* ecliptic longitude at epoch (radians) */
#define SOLAR_EG        4.8765075783

/* Ecliptic longitude at perigee (radians)*/
#define SOLAR_MG        4.93523998457

/* Eccentricity of orbit (degrees?) */
#define SOLAR_E         0.016713

/* Semi-major axis, in km */
#define SOLAR_R0        149598500

/* Angular diameter at r = r0 (radians) */
#define SOLAR_A         0.00930483893

/* Radians per day (angular velocity) */
#define SOLAR_RpD       (PI_2/365.242191)

/* geocentric parallax, in radians */
#define SOLAR_P         0.00004263452

/*
 * Lunar constants
 */

/* Mean Longitude at epoch (radians) */
//#define MOON_L0 (318.351648 * DR)
#define MOON_L0 5.5562844368
/* Mean Longitude of the perigee at epoch */
//#define MOON_P0 (36.340410 * DR)
#define MOON_P0 0.6342598060

/* Mean Longitude of the node at epoch */
//#define MOON_N0 (318.510107 * DR)
#define MOON_N0 5.5590500680

/* Inclination of the moon's orbit */
//#define MOON_I  (5.145396 * DR)
#define MOON_I  0.08980410

/* Eccentricity of the moon's orbit */
#define MOON_E  0.054900

/* Semi-Major Axis of the Moon's Orbit */
#define MOON_U  384401

/* Moon's Angular size at distance U from Earth (radians) */
#define MOON_A  0.0090425509
//#define MOON_A  (0.5181 * DR)

/* Parallax at distance U from Earth: (radians) */
#define MOON_P  0.0165928452
//#define MOON_P  (0.9507 * DR)

#endif // constants_h

